==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ScatterPolygonSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescriptionMetadata } from "./StyleDescriptionMetadata";
import { ShapeSeriesBaseDescriptionMetadata } from "./ShapeSeriesBaseDescriptionMetadata";
import { ScatterPolygonSeriesDescription } from "./ScatterPolygonSeriesDescription";
/**
 * @hidden
 */
var ScatterPolygonSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterPolygonSeriesDescriptionMetadata, _super);
    function ScatterPolygonSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterPolygonSeriesDescriptionMetadata.b = function (a) {
        if (ScatterPolygonSeriesDescriptionMetadata.a == null) {
            ScatterPolygonSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterPolygonSeriesDescriptionMetadata.c(ScatterPolygonSeriesDescriptionMetadata.a);
        }
        if (a.g(ScatterPolygonSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(ScatterPolygonSeriesDescriptionMetadata.a);
        StyleDescriptionMetadata.d(a);
    };
    ScatterPolygonSeriesDescriptionMetadata.c = function (a) {
        ShapeSeriesBaseDescriptionMetadata.c(a);
        a.item("ShapeStyle", "ExportedType:Style");
        a.item("MarkerType", "ExportedType:string:MarkerType");
        a.item("MarkerType@names", "Unset;None;Automatic;Circle;Triangle;Pyramid;Square;Diamond;Pentagon;Hexagon;Tetragram;Pentagram;Hexagram;Hidden");
        a.item("MarkerTemplateRef", "(w:MarkerTemplate,wf:MarkerTemplate)DataRef::object");
        a.item("MarkerThickness", "Number:double");
        a.item("ActualMarkerTemplateRef", "(w:ActualMarkerTemplate,wf:ActualMarkerTemplate)DataRef::object");
        a.item("MarkerBrush", "Brush");
        a.item("ActualMarkerBrush", "Brush");
        a.item("MarkerOutline", "Brush");
        a.item("ActualMarkerOutline", "Brush");
        a.item("MarkerCollisionAvoidance", "ExportedType:string:CollisionAvoidanceType");
        a.item("MarkerCollisionAvoidance@names", "None;Omit;Fade;OmitAndShift;FadeAndShift");
        a.item("MarkerOutlineMode", "ExportedType:string:MarkerOutlineMode");
        a.item("MarkerOutlineMode@names", "Auto;Normal;MatchMarkerBrush");
        a.item("MarkerFillMode", "ExportedType:string:MarkerFillMode");
        a.item("MarkerFillMode@names", "Auto;Normal;MatchMarkerOutline");
    };
    ScatterPolygonSeriesDescriptionMetadata.d = function (a) {
        ScatterPolygonSeriesDescriptionMetadata.b(a);
        a.u("ScatterPolygonSeries", function () { return new ScatterPolygonSeriesDescription(); });
        a.t("ScatterPolygonSeries", ScatterPolygonSeriesDescriptionMetadata.a);
    };
    ScatterPolygonSeriesDescriptionMetadata.$t = markType(ScatterPolygonSeriesDescriptionMetadata, 'ScatterPolygonSeriesDescriptionMetadata');
    ScatterPolygonSeriesDescriptionMetadata.a = null;
    return ScatterPolygonSeriesDescriptionMetadata;
}(Base));
export { ScatterPolygonSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ScatterPolygonSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescriptionMetadata } from "./StyleDescriptionMetadata";
import { ShapeSeriesBaseDescriptionMetadata } from "./ShapeSeriesBaseDescriptionMetadata";
import { ScatterPolygonSeriesDescription } from "./ScatterPolygonSeriesDescription";
/**
 * @hidden
 */
var ScatterPolygonSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterPolygonSeriesDescriptionMetadata, _super);
    function ScatterPolygonSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterPolygonSeriesDescriptionMetadata.b = function (a) {
        if (ScatterPolygonSeriesDescriptionMetadata.a == null) {
            ScatterPolygonSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterPolygonSeriesDescriptionMetadata.c(ScatterPolygonSeriesDescriptionMetadata.a);
        }
        if (a.j(ScatterPolygonSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(ScatterPolygonSeriesDescriptionMetadata.a);
        StyleDescriptionMetadata.d(a);
    };
    ScatterPolygonSeriesDescriptionMetadata.c = function (a) {
        ShapeSeriesBaseDescriptionMetadata.c(a);
        a.item("ShapeStyle", "ExportedType:Style");
        a.item("MarkerType", "ExportedType:string:MarkerType");
        a.item("MarkerType@names", "Unset;None;Automatic;Circle;Triangle;Pyramid;Square;Diamond;Pentagon;Hexagon;Tetragram;Pentagram;Hexagram;Hidden");
        a.item("MarkerTemplateRef", "(w:MarkerTemplate,wf:MarkerTemplate)DataRef::object");
        a.item("MarkerThickness", "Number:double");
        a.item("ActualMarkerTemplateRef", "(w:ActualMarkerTemplate,wf:ActualMarkerTemplate)DataRef::object");
        a.item("MarkerBrush", "Brush");
        a.item("ActualMarkerBrush", "Brush");
        a.item("MarkerOutline", "Brush");
        a.item("ActualMarkerOutline", "Brush");
        a.item("MarkerCollisionAvoidance", "ExportedType:string:CollisionAvoidanceType");
        a.item("MarkerCollisionAvoidance@names", "None;Omit;Fade;OmitAndShift;FadeAndShift");
        a.item("MarkerOutlineMode", "ExportedType:string:MarkerOutlineMode");
        a.item("MarkerOutlineMode@names", "Auto;Normal;MatchMarkerBrush");
        a.item("MarkerFillMode", "ExportedType:string:MarkerFillMode");
        a.item("MarkerFillMode@names", "Auto;Normal;MatchMarkerOutline");
    };
    ScatterPolygonSeriesDescriptionMetadata.d = function (a) {
        ScatterPolygonSeriesDescriptionMetadata.b(a);
        a.aa("ScatterPolygonSeries", function () { return new ScatterPolygonSeriesDescription(); });
        a.z("ScatterPolygonSeries", ScatterPolygonSeriesDescriptionMetadata.a);
    };
    ScatterPolygonSeriesDescriptionMetadata.$t = markType(ScatterPolygonSeriesDescriptionMetadata, 'ScatterPolygonSeriesDescriptionMetadata');
    ScatterPolygonSeriesDescriptionMetadata.a = null;
    return ScatterPolygonSeriesDescriptionMetadata;
}(Base));
export { ScatterPolygonSeriesDescriptionMetadata };
